"use strict";
exports.__esModule = true;
var BoldRenderer_1 = require("./BoldRenderer");
var CodeRenderer_1 = require("./CodeRenderer");
var CodeBlockRenderer_1 = require("./CodeBlockRenderer");
var NullRenderer_1 = require("./NullRenderer");
var HeaderRenderer_1 = require("./HeaderRenderer");
var ImageRenderer_1 = require("./ImageRenderer");
var ItalicsRenderer_1 = require("./ItalicsRenderer");
var LineBreakRenderer_1 = require("./LineBreakRenderer");
var LinkRenderer_1 = require("./LinkRenderer");
var ListItemRenderer_1 = require("./ListItemRenderer");
var ListRenderer_1 = require("./ListRenderer");
var ParagraphRenderer_1 = require("./ParagraphRenderer");
var TextRenderer_1 = require("./TextRenderer");
var getCustomRenderer = function (node, options) {
    if (options) {
        var customRenderers = options.customRenderers;
        if (customRenderers)
            return customRenderers[node.type];
    }
};
var getRendererByNodeType = function (node, options) {
    var CustomRenderer = getCustomRenderer(node, options);
    if (CustomRenderer)
        return new CustomRenderer(node, options);
    switch (node.type) {
        case 'code':
            return new CodeRenderer_1["default"](node, options);
        case 'code_block':
            return new CodeBlockRenderer_1["default"](node, options);
        case 'document':
            return new NullRenderer_1["default"](node, options);
        case 'emph':
            return new ItalicsRenderer_1["default"](node, options);
        case 'heading':
            return new HeaderRenderer_1["default"](node, options);
        case 'image':
            return new ImageRenderer_1["default"](node, options);
        case 'item':
            return new ListItemRenderer_1["default"](node, options);
        case 'link':
            return new LinkRenderer_1["default"](node, options);
        case 'list':
            return new ListRenderer_1["default"](node, options);
        case 'paragraph':
            return new ParagraphRenderer_1["default"](node, options);
        case 'softbreak':
            return new LineBreakRenderer_1["default"](node, options);
        case 'strong':
            return new BoldRenderer_1["default"](node, options);
        case 'text':
            return new TextRenderer_1["default"](node, options);
        default:
            console.log('Unsupported type: ' + node.type);
            return new NullRenderer_1["default"](node, options);
    }
};
exports["default"] = getRendererByNodeType;
